@@ -1,22 +1,7 @@
-/*  This file is part of the KDevelop PHP Documentation Plugin
+/*
+    SPDX-FileCopyrightText: 2012 Milian Wolff <mail@milianw.de>
 
-    Copyright 2012 Milian Wolff <mail@milianw.de>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "phpdocsplugin.h"
@@ -40,7 +25,7 @@
 #include <language/duchain/classmemberdeclaration.h>
 #include <language/duchain/classfunctiondeclaration.h>
 
-#include <QtCore/QFile>
+#include <QFile>
 
 #include "phpdocsdebug.h"
 #include "phpdocumentation.h"
@@ -51,15 +36,14 @@ using namespace KDevelop;
 K_PLUGIN_FACTORY_WITH_JSON(PhpDocsFactory, "kdevphpdocs.json", registerPlugin<PhpDocsPlugin>();)
 
 PhpDocsPlugin::PhpDocsPlugin(QObject* parent, const QVariantList& args)
-    : IPlugin("kdevphpdocs", parent)
+    : IPlugin(QStringLiteral("kdevphpdocs"), parent)
     , m_model(new PhpDocsModel(this))
 {
-    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IDocumentationProvider )
     Q_UNUSED(args);
 
     readConfig();
 
-    KSettings::Dispatcher::registerComponent( "kdevphpdocs_config", this, "readConfig" );
+    KSettings::Dispatcher::registerComponent( QStringLiteral("kdevphpdocs_config"), this, "readConfig" );
 }
 
 PhpDocsPlugin::~PhpDocsPlugin()
@@ -73,7 +57,7 @@ QString PhpDocsPlugin::name() const
 
 QIcon PhpDocsPlugin::icon() const
 {
-    static QIcon icon = QIcon::fromTheme("application-x-php");
+    static QIcon icon = QIcon::fromTheme(QStringLiteral("application-x-php"));
     return icon;
 }
 
@@ -102,9 +86,9 @@ QString PhpDocsPlugin::getDocumentationFilename( KDevelop::Declaration* dec, con
                 fname = className + '.' + fdec->identifier().toString();
             } else {
                 if ( fdec->isConstructor() ) {
-                    fname = "construct";
+                    fname = QStringLiteral("construct");
                 } else if ( fdec->isDestructor() ) {
-                    fname = "destruct";
+                    fname = QStringLiteral("destruct");
                 } else {
                     fname = fdec->identifier().toString();
                 }
@@ -118,21 +102,21 @@ QString PhpDocsPlugin::getDocumentationFilename( KDevelop::Declaration* dec, con
         fname = "function." + dec->identifier().toString();
     }
     // check for superglobals / reserved variables
-    else if ( dec->identifier() == Identifier("GLOBALS") ||
-                dec->identifier() == Identifier("php_errormsg") ||
-                dec->identifier() == Identifier("HTTP_RAW_POST_DATA") ||
-                dec->identifier() == Identifier("http_response_header") ||
-                dec->identifier() == Identifier("argc") ||
-                dec->identifier() == Identifier("argv") ||
-                dec->identifier() == Identifier("_GET") ||
-                dec->identifier() == Identifier("_POST") ||
-                dec->identifier() == Identifier("_FILES") ||
-                dec->identifier() == Identifier("_REQUEST") ||
-                dec->identifier() == Identifier("_SESSION") ||
-                dec->identifier() == Identifier("_ENV") ||
-                dec->identifier() == Identifier("_COOKIE") ) {
+    else if ( dec->identifier() == Identifier(QStringLiteral("GLOBALS")) ||
+                dec->identifier() == Identifier(QStringLiteral("php_errormsg")) ||
+                dec->identifier() == Identifier(QStringLiteral("HTTP_RAW_POST_DATA")) ||
+                dec->identifier() == Identifier(QStringLiteral("http_response_header")) ||
+                dec->identifier() == Identifier(QStringLiteral("argc")) ||
+                dec->identifier() == Identifier(QStringLiteral("argv")) ||
+                dec->identifier() == Identifier(QStringLiteral("_GET")) ||
+                dec->identifier() == Identifier(QStringLiteral("_POST")) ||
+                dec->identifier() == Identifier(QStringLiteral("_FILES")) ||
+                dec->identifier() == Identifier(QStringLiteral("_REQUEST")) ||
+                dec->identifier() == Identifier(QStringLiteral("_SESSION")) ||
+                dec->identifier() == Identifier(QStringLiteral("_ENV")) ||
+                dec->identifier() == Identifier(QStringLiteral("_COOKIE")) ) {
         if ( isLocal ) {
-            fname = QString("reserved.variables.") + dec->identifier().toString().remove('_');
+            fname = QStringLiteral("reserved.variables.") + dec->identifier().toString().remove('_');
         } else {
             fname = dec->identifier().toString();
         }
@@ -175,12 +159,21 @@ IDocumentation::Ptr PhpDocsPlugin::documentationForDeclaration( Declaration* dec
         }
 
         qCDebug(DOCS) << "php documentation located at " << url << "for" << dec->toString();
-        return documentationForUrl(url, dec->qualifiedIdentifier().toString(), dec->comment());
+        return documentationForUrl(url, dec->qualifiedIdentifier().toString());
     }
 
     return {};
 }
 
+IDocumentation::Ptr PhpDocsPlugin::documentation(const QUrl& url) const
+{
+    if (url.toString().startsWith(PhpDocsSettings::phpDocLocation().toString())) {
+        return documentationForUrl(url, QString());
+    }
+    return {};
+}
+
+
 QAbstractListModel* PhpDocsPlugin::indexModel() const
 {
     return m_model;
@@ -200,10 +193,10 @@ void PhpDocsPlugin::loadUrl(const QUrl& url) const
     ICore::self()->documentationController()->showDocumentation(doc);
 }
 
-void PhpDocsPlugin::addToHistory(const QUrl& url)
+void PhpDocsPlugin::showDocumentation(const QUrl& url)
 {
     auto doc = documentationForUrl(url, url.toString());
-    emit addHistory(doc);
+    ICore::self()->documentationController()->showDocumentation(doc);
 }
 
 IDocumentation::Ptr PhpDocsPlugin::documentationForUrl(const QUrl& url, const QString& name, const QByteArray& description) const
